#!/usr/bin/python
"Create the package description index"

import xapian, re, gzip, deb822

tokenizer = re.compile("[^A-Za-z0-9_-]+")
# How we normalize tokens before indexing
stemmer = xapian.Stem("english")
def normalise(word):
	return stemmer.stem_word(word.lower()) 

# Index all packages
# ( wget -c http://people.debian.org/~enrico/AllPackages.gz )
database = xapian.WritableDatabase( \
	"descindex", xapian.DB_CREATE_OR_OPEN)
input = gzip.GzipFile("AllPackages.gz")
for p in deb822.Packages.iter_paragraphs(input):
	idx = 1
	doc = xapian.Document()
	doc.set_data(p["Package"]);
	doc.add_posting(normalise(p["Package"]), idx);
	idx += 1
	for tok in tokenizer.split(p["Description"]):
		if len(tok) == 0: continue
		doc.add_posting(normalise(tok), idx);
		idx += 1
	database.add_document(doc);
database.flush()
